$.jqplot.MekkoAxisRenderer

An axis renderer for a Mekko chart. Should be used with a Mekko chart where the mekkoRenderer is used on the series. Displays the Y axis as a range from 0 to 1 (0 to 100%) and the x axis with a tick for each series scaled to the sum of all the y values.

Summary

$.jqplot.MekkoAxisRenderer | An axis renderer for a Mekko chart.
Properties |
tickMode | How to space the ticks on the axis.
barLabelRenderer | renderer to use to draw labels under each bar.
barLabels | array of labels to put under each bar.
barLabelOptions | options object to pass to the bar label renderer.

### Properties

### tickMode

> this.tickMode

How to space the ticks on the axis. ‘bar’ will place a tick at the width of each bar. This is the default for the x axis. ‘even’ will place ticks at even intervals. This is the default for x2 axis and y axis. y axis cannot be changed.

### barLabelRenderer

> this.barLabelRenderer = $.jqplot.AxisLabelRenderer

renderer to use to draw labels under each bar.

### barLabels

> this.barLabels = this.barLabels || []

array of labels to put under each bar.

### barLabelOptions

> this.barLabelOptions = {}

options object to pass to the bar label renderer.

> this.tickMode

How to space the ticks on the axis.

> this.barLabelRenderer = $.jqplot.AxisLabelRenderer

renderer to use to draw labels under each bar.

> this.barLabels = this.barLabels || []

array of labels to put under each bar.

> this.barLabelOptions = {}

options object to pass to the bar label renderer.
Close